@@ -6,7 +6,6 @@ import sys
 
 from ffmpeg import probe
 from tqdm import tqdm
-from .utils import FileInfoProvider
 
 
 class FfmpegProcess:
@@ -16,8 +15,18 @@ class FfmpegProcess:
         Accepts an optional ffmpeg_loglevel parameter to set the value of FFmpeg's -loglevel argument.
         """
         self._command = command
-        # pipe:1 sends the progress to stdout. See https://stackoverflow.com/a/54386052/13231825
-        self._ffmpeg_args = command + ["-progress", "pipe:1", "-nostats", "-loglevel", ffmpeg_loglevel]
+        self._can_get_duration = True
+
+        try:
+            duration_secs = float(probe(filepath)["format"]["duration"])
+        except Exception:
+            self._can_get_duration = False
+
+        self._ffmpeg_args = command + ["-loglevel", ffmpeg_loglevel]
+
+        if self._can_get_duration:
+            # pipe:1 sends the progress to stdout. See https://stackoverflow.com/a/54386052/13231825
+            self._ffmpeg_args += ["-progress", "pipe:1", "-nostats"] 
 
     def run(self, progress_handler=None, ffmpeg_output_file=None):
         """
@@ -39,18 +48,13 @@ class FfmpegProcess:
         with open(ffmpeg_output_file, "w") as f:
             pass
 
-        try:
-            duration_secs = float(probe(filepath)["format"]["duration"])
-        except Exception:
-            can_get_duration = False
-        else:
-            can_get_duration = True
-
         print(f"Running: {' '.join(self._ffmpeg_args)}")
         popen_args = [self._ffmpeg_args]
 
-        if can_get_duration:
-            popen_args.append(stdout=subprocess.PIPE, stderr=f)
+        if self._can_get_duration:
+            print('IN DURATION')
+            popen_args.append(stdout=subprocess.PIPE)
+            popen_args.append(stderr=f)
 
             with open(ffmpeg_output_file, "a") as f:
                 self._process = subprocess.Popen(*popen_args)
@@ -63,11 +67,12 @@ class FfmpegProcess:
             progress_bar.clear()
             previous_seconds_processed = 0
         else:
+            print('ELSE')
             self._process = subprocess.Popen(*popen_args)
 
         try:
             while self._process.poll() is None:
-                if can_get_duration:
+                if self._can_get_duration:
                     line = self._process.stdout.readline().decode("utf-8")
                     # Format: out_time_ms=3505000
                     if "out_time_ms" in line:
